@@ -231,6 +231,9 @@ class LEDETAuxiliary:
     iContactAlongHeight_pairs_to_add: np.ndarray = np.array([])
     iContactAlongHeight_pairs_to_remove: np.ndarray = np.array([])
     th_insulationBetweenLayers: np.ndarray = np.array([])
+    # The following parameters are needed for by-passing self-mutual inductance calculation
+    flag_calculate_inductance: bool = None
+    overwrite_inductance_coil_sections: np.ndarray = np.array([[]])
     # The following parameters are needed for self-mutual inductance calculation
     nStrands_inGroup_ROXIE: np.ndarray = np.array([])
     x_strands: np.ndarray = np.array([])  # TODO: add correct keys based on the ParserROXIE() parameters
