@@ -32,14 +32,6 @@ class Model(BaseModel):
     state: str = None
 
 
-class MagnetInductance(BaseModel):
-    """
-        Level 2: Class for magnet inductance assignment
-    """
-    fL_I: List[float] = []
-    fL_L: List[float] = []
-
-
 class General(BaseModel):
     """
         Level 1: Class for general information on the case study
@@ -50,7 +42,6 @@ class General(BaseModel):
     magnet_type: str = None
     T_initial: float = None               # T00 (LEDET), Top (SIGMA)
     magnetic_length: float = None   # l_magnet (LEDET), magLength (SIGMA), magneticLength (ProteCCT)
-    magnet_inductance: MagnetInductance = MagnetInductance()
 
 
 ############################
@@ -63,26 +54,11 @@ class ElectricalOrder(BaseModel):
     reversed: List[int] = []         # elPairs_RevElOrder
 
 
-class HeatExchange(BaseModel):
-    """
-        Level 2: Class for heat exchange information
-    """
-    heat_exchange_max_distance: float = None  # heat exchange max_distance
-    iContactAlongWidth_pairs_to_add: List[List[int]] = [[]]
-    iContactAlongWidth_pairs_to_remove: List[List[int]] = [[]]
-    iContactAlongHeight_pairs_to_add: List[List[int]] = [[]]
-    iContactAlongHeight_pairs_to_remove: List[List[int]] = [[]]
-    th_insulationBetweenLayers: float = None
-
-
 class Multipole(BaseModel):
     """
         Level 2: Class for multi-pole coil data
     """
-    alphaDEG_ht: List[float] = []  # Inclination angle of each half-turn, alphaDEG (LEDET)
-    rotation_ht: List[float] = []  # Rotation of each half-turn, rotation_block (LEDET)
-    mirror_ht: List[float]   = []  # Mirror around quadrant bisector line for half-turn, mirror_block (LEDET)
-    mirrorY_ht: List[float]  = []  # Mirror around Y axis for half-turn, mirrorY_block (LEDET)
+    tbc: str = None
 
 
 class Solenoid(BaseModel):
@@ -127,7 +103,6 @@ class CoilWindings(BaseModel):
     n_half_turn_in_group: List[int] = []
     half_turn_length: List[float] = []
     electrical_pairs: ElectricalOrder = ElectricalOrder()  # Variables used to calculate half-turn electrical order
-    heat_exchange: HeatExchange = HeatExchange()  # Variables used to calculate heat exchange
     multipole: Multipole = Multipole()
     pancake: Pancake = Pancake()
     solenoid: Solenoid = Solenoid()
@@ -188,15 +163,15 @@ class QuenchHeater(BaseModel):
     w: List[float] = []
     h: List[float] = []
     s_ins: List[float] = []
-    type_ins: List[float] = []
+    type_ins: List[int] = []
     s_ins_He: List[float] = []
-    type_ins_He: List[float] = []
+    type_ins_He: List[int] = []
     l: List[float] = []
     l_copper: List[float] = []
     l_stainless_steel: List[float] = []
     f_cover: List[float] = []
-    iQH_toHalfTurn_From: List[float] = []
-    iQH_toHalfTurn_To: List[float] = []
+    iQH_toHalfTurn_From: List[int] = []
+    iQH_toHalfTurn_To: List[int] = []
 
 
 class CLIQ(BaseModel):
@@ -274,23 +249,13 @@ class QuenchInitializationBBQ(BaseModel):
     sigmaTInit: float = None
 
 
-class BBQ(BaseModel):
-    """
-        Level 1: Class for BBQ options
-    """
-    geometry: GeometryBBQ = GeometryBBQ()
-    simulation: SimulationBBQ = SimulationBBQ()
-    physics: PhysicsBBQ = PhysicsBBQ()
-    quench_initialization: QuenchInitializationBBQ = QuenchInitializationBBQ()
-
-
 ############################
-# getDP options
-class GETDP(BaseModel):
+# FiQuS options
+class FiQuS(BaseModel):
     """
-        Level 1: Class for getDP options
+        Level 1: Class for FiQuS options
     """
-    placeholder_parameter: int = None
+    tbc: int = None
 
 
 ############################
@@ -302,6 +267,38 @@ class TimeVectorLEDET(BaseModel):
     time_vector_params: List[float] = []
 
 
+class MagnetInductance(BaseModel):
+    """
+        Level 2: Class for magnet inductance assignment
+    """
+    flag_calculate_inductance: bool = None
+    overwrite_inductance_coil_sections: List[List[float]] = [[]]
+    LUT_DifferentialInductance_current: List[float] = []
+    LUT_DifferentialInductance_inductance: List[float] = []
+
+
+class HeatExchange(BaseModel):
+    """
+        Level 2: Class for heat exchange information
+    """
+    heat_exchange_max_distance: float = None  # heat exchange max_distance
+    iContactAlongWidth_pairs_to_add: List[List[int]] = [[]]
+    iContactAlongWidth_pairs_to_remove: List[List[int]] = [[]]
+    iContactAlongHeight_pairs_to_add: List[List[int]] = [[]]
+    iContactAlongHeight_pairs_to_remove: List[List[int]] = [[]]
+    th_insulationBetweenLayers: float = None
+
+
+class ConductorGeometry(BaseModel):
+    """
+        Level 2: Class for multipole geometry parameters - ONLY USED FOR ISCC/ISCL CALCULATION
+    """
+    alphaDEG_ht: List[float] = []  # Inclination angle of each half-turn, alphaDEG (LEDET)
+    rotation_ht: List[float] = []  # Rotation of each half-turn, rotation_block (LEDET)
+    mirror_ht: List[int]   = []  # Mirror around quadrant bisector line for half-turn, mirror_block (LEDET)
+    mirrorY_ht: List[int]  = []  # Mirror around Y axis for half-turn, mirrorY_block (LEDET)
+
+
 class FieldMapFilesLEDET(BaseModel):
     """
         Level 2: Class for field map file parameters in LEDET
@@ -321,7 +318,7 @@ class InputGenerationOptionsLEDET(BaseModel):
     """
         Level 2: Class for input generation options in LEDET
     """
-    flag_typeWindings: int = None
+    # flag_typeWindings: int = None
     flag_calculateInductanceMatrix: int = None
     flag_useExternalInitialization: int = None
     flag_initializeVar: int = None
@@ -331,9 +328,9 @@ class SimulationLEDET(BaseModel):
     """
         Level 2: Class for simulation options in LEDET
     """
-    flag_fastMode: float = None
-    flag_controlCurrent: float = None
-    flag_automaticRefinedTimeStepping: float = None
+    flag_fastMode: int = None
+    flag_controlCurrent: int = None
+    flag_automaticRefinedTimeStepping: int = None
 
 
 class PhysicsLEDET(BaseModel):
@@ -403,18 +400,18 @@ class Simulation3DLEDET(BaseModel):
 
     # Variables in the "Inputs" sheet
     sim3D_uThreshold: float = None
-    sim3D_f_cooling_down: Union[float, int] = None
-    sim3D_f_cooling_up: Union[float, int] = None
-    sim3D_f_cooling_left: Union[float, int] = None
-    sim3D_f_cooling_right: Union[float, int] = None
+    sim3D_f_cooling_down: Union[float, List[float]] = None
+    sim3D_f_cooling_up: Union[float, List[float]] = None
+    sim3D_f_cooling_left: Union[float, List[float]] = None
+    sim3D_f_cooling_right: Union[float, List[float]] = None
     sim3D_f_cooling_LeadEnds: List[int] = []
     sim3D_fExToIns: float = None
     sim3D_fExUD: float = None
     sim3D_fExLR: float = None
     sim3D_min_ds_coarse: float = None
     sim3D_min_ds_fine: float = None
-    sim3D_min_nodesPerStraightPart: float = None
-    sim3D_min_nodesPerEndsPart: float = None
+    sim3D_min_nodesPerStraightPart: int = None
+    sim3D_min_nodesPerEndsPart: int = None
     sim3D_idxFinerMeshHalfTurn: List[int] = []
     sim3D_flag_checkNodeProximity: int = None
     sim3D_nodeProximityThreshold: float = None
@@ -424,7 +421,7 @@ class Simulation3DLEDET(BaseModel):
     sim3D_tShortCircuit: float = None
     sim3D_coilSectionsShortCircuit: List[int] = []
     sim3D_R_shortCircuit: float = None
-    sim3D_shortCircuitPosition: float = None
+    sim3D_shortCircuitPosition: Union[float, List[List[float]]] = None
     sim3D_durationGIF: float = None
     sim3D_flag_saveFigures: int = None
     sim3D_flag_saveGIF: int = None
@@ -470,6 +467,9 @@ class LEDET(BaseModel):
         Level 1: Class for LEDET options
     """
     time_vector: TimeVectorLEDET = TimeVectorLEDET()
+    magnet_inductance: MagnetInductance = MagnetInductance()
+    heat_exchange: HeatExchange = HeatExchange()
+    conductor_geometry_used_for_ISCL: ConductorGeometry = ConductorGeometry()
     field_map_files: FieldMapFilesLEDET = FieldMapFilesLEDET()
     input_generation_options: InputGenerationOptionsLEDET = InputGenerationOptionsLEDET()
     simulation: SimulationLEDET = SimulationLEDET()
@@ -481,6 +481,7 @@ class LEDET(BaseModel):
     variables_to_save: VariablesToSaveLEDET = VariablesToSaveLEDET()
 
 
+
 ############################
 # ProteCCT options
 class TimeVectorProteCCT(BaseModel):
@@ -637,8 +638,7 @@ class DataModelMagnet(BaseModel):
     Circuit: Circuit = Circuit()
     Power_Supply: PowerSupply = PowerSupply()
     Quench_Protection: QuenchProtection = QuenchProtection()
-    Options_BBQ: BBQ = BBQ()
-    Options_getDP: GETDP = GETDP()
+    Options_FiQuS: FiQuS = FiQuS()
     Options_LEDET: LEDET = LEDET()
     Options_ProteCCT: PROTECCT = PROTECCT()
     Options_SIGMA: SIGMA = SIGMA()
