@@ -121,6 +121,7 @@ def get_template_LEDET_inputs_sheet():
         ['sim3D_f_cooling_up', None, 'Scaling factor for cooling to thermal sink - Conductor up side'],
         ['sim3D_f_cooling_left', None, 'Scaling factor for cooling to thermal sink - Conductor right side'],
         ['sim3D_f_cooling_right', None, 'Scaling factor for cooling to thermal sink - Conductor left side'],
+        ['sim3D_f_cooling_LeadEnds', None, 'Flag for cooling to thermal sink - Two lead ends. This must be a 2-element vector (first/positive lead and last/negative lead) whose values are either 0 or 1.'],
         ['sim3D_fExToIns', None, 'Scaling factor for the heat exchange between bare conductor and insulation'],
         ['sim3D_fExUD', None, 'Scaling factor for the thermal diffusion between conductors along the wider conductor side (UD-->Up/Down)'],
         ['sim3D_fExLR', None, 'Scaling factor for the thermal diffusion between conductors along the narrower conductor side (LR-->Left/Right)'],
@@ -129,6 +130,8 @@ def get_template_LEDET_inputs_sheet():
         ['sim3D_min_nodesPerStraightPart', None, 'Minimum number of nodes in each straight-section part [-]'],
         ['sim3D_min_nodesPerEndsPart', None, 'Minimum number of nodes in each end-section part [-]'],
         ['sim3D_idxFinerMeshHalfTurn', None, 'Indices of the half-turns with finer mesh (in LEDET half-turn order, NOT in electrical order) [-]'],
+        ['sim3D_flag_checkNodeProximity', None, 'If set to one, a proximity check will be performed: only the nodes whose center is closer than the threshold “sim3D_nodeProximityThreshold” will be thermally connected [-]. (default=0)'],
+        ['sim3D_nodeProximityThreshold', None, 'Threshold to use in the proximity check (if activated) [m]. (default=0.01 m)'],
         ['sim3D_Tpulse_sPosition', None, 'Center of the temperature gaussian distribution, i.e. position where the quench starts [m]'],
         ['sim3D_Tpulse_peakT', None, 'Peak temperature of the gaussian distribution [K]'],
         ['sim3D_Tpulse_width', None, 'Width of the temperature gaussian distribution, i.e. 2*sigma [m]'],
@@ -213,8 +216,9 @@ def get_template_LEDET_options_sheet():
         ['flag_saveFigures', None, 'Save figures showing the main results'],
         ['flag_saveMatFile', None, 'Save main simulation results in a mat file (0=do not save; 1=save most variables; 2=save only most relevant variables)'],
         ['flag_saveTxtFiles', None, 'Save selected variables in a txt files. The variables are defined in the "Variables" sheet'],
+        ['flag_saveResultsToMesh', None, 'Save selected variables and assign them to a given mesh of elements. The variables are defined in the "Variables" sheet  (default: No)'],
         ['flag_generateReport', None, 'Generate a report summarizing the simulation results (default: Yes)'],
-        ['flag_hotSpotTemperatureInEachGroup', None, 'If set to 1, calculate the hot-spot temperature in each group instead of in each coil section (default: No)'],
+        ['flag_hotSpotTemperatureInEachGroup', None, 'Calculate the hot-spot temperature in each group instead of in each coil section (default: No)'],
         [None, None, None],
         [None, None, '3D Simulation Options'],
         ['flag_3D', None, 'If set to 1, the 3D model will run instead of the default 2D'],
@@ -257,5 +261,12 @@ def get_template_LEDET_variables_sheet():
         ['variableToSaveTxt', None, 'Variables to save'],
         ['typeVariableToSaveTxt', None, 'Flag determining the variable type: Flag 1 saves the entire variable history; Flag 2 saves the variable final state. Histories and final states are saved in separate files.'],
         ['variableToInitialize', None, 'Variables to load from exchange files'],
+        [None, None, None],
+        [None, None, 'Variables for assigning variables to mesh elements (each column is a different output)'],
+        ['writeToMesh_fileNameMeshPositions', None, 'Name of the file defining the mesh element centers'],
+        ['writeToMesh_suffixFileNameOutput', None, 'Name of the suffix of the output files. Full names will be magnet_name + suffix + simulation_number + time_step + ".RES"'],
+        ['writeToMesh_selectedVariables', None, 'Selected variables that will be written to the mesh elements. More than one can be defined in each column (comma separated).'],
+        ['writeToMesh_selectedTimeSteps', None, 'Selected time steps at which the results will be written to the mesh elements'],
+        ['writeToMesh_selectedMethod', None, 'Method for assigning variables to nodes. 1=Assign to each mesh node the value of the closest strand (good for distributed properties like temperature).2=Assign the value of each strand to the closest node (good for electromagnetic forces)'],
     ]
     return template_LEDET_variables_sheet
\ No newline at end of file
