@@ -201,10 +201,11 @@ class ParserPSPICE:
                     nodes = line_split[0].split(' ')
                     line_split = line_split[1].split('=')
                     value = line_split[1].strip(' { } ')  # Strip spaces and bracket at the extremities
-                    self.circuit_data.Netlist[name] = Component()
-                    self.circuit_data.Netlist[name].type = 'stimulus-controlled component'
-                    self.circuit_data.Netlist[name].nodes = nodes
-                    self.circuit_data.Netlist[name].value = str(value)
+                    new_Component = Component()
+                    new_Component.type = 'stimulus-controlled component'
+                    new_Component.nodes = nodes
+                    new_Component.value = str(value)
+                    self.circuit_data.Netlist.__setattr__(name, new_Component)
                     continue
 
                 # Special case: Pulsed power source
@@ -216,10 +217,11 @@ class ParserPSPICE:
                     nodes = line_before.split(' ')
                     line_after = line_after.partition('PULSE')[2]  # Take the part of the string after the first "VALUE " chars
                     value = line_after.strip(' ( ) ')  # Strip spaces and bracket at the extremities
-                    self.circuit_data.Netlist[name] = Component()
-                    self.circuit_data.Netlist[name].type  = 'pulsed-source component'
-                    self.circuit_data.Netlist[name].nodes = nodes
-                    self.circuit_data.Netlist[name].value = str(value)
+                    new_Component = Component()
+                    new_Component.type = 'pulsed-source component'
+                    new_Component.nodes = nodes
+                    new_Component.value = str(value)
+                    self.circuit_data.Netlist.__setattr__(name, new_Component)
                     continue
 
                 # Special case: Controlled-source component
@@ -243,10 +245,11 @@ class ParserPSPICE:
                     nodes = line_before.split(' ')
                     line_after = line_after.partition(delimiter_value)[2]  # Take the part of the string after the first "delimiter_value" chars
                     value = line_after.strip(' { } ')  # Strip spaces and bracket at the extremities
-                    self.circuit_data.Netlist[name] = Component()
-                    self.circuit_data.Netlist[name].type  = 'controlled-source component'
-                    self.circuit_data.Netlist[name].nodes = nodes
-                    self.circuit_data.Netlist[name].value = str(value)
+                    new_Component = Component()
+                    new_Component.type = 'controlled-source component'
+                    new_Component.nodes = nodes
+                    new_Component.value = str(value)
+                    self.circuit_data.Netlist.__setattr__(name, new_Component)
                     continue
 
                 # Special case: Parametrized component
@@ -258,10 +261,11 @@ class ParserPSPICE:
                     nodes = line_before.split(' ')
                     value = line_after.strip(' { } ')  # Strip spaces and bracket at the extremities
                     self.name_last_component = name
-                    self.circuit_data.Netlist[name] = Component()
-                    self.circuit_data.Netlist[name].type  = 'parametrized component'
-                    self.circuit_data.Netlist[name].nodes = nodes
-                    self.circuit_data.Netlist[name].value = str(value)
+                    new_Component = Component()
+                    new_Component.type = 'parametrized component'
+                    new_Component.nodes = nodes
+                    new_Component.value = str(value)
+                    self.circuit_data.Netlist.__setattr__(self.name_last_component, new_Component)
                     continue
 
                 # Special case: Parameters of a parametrized component
@@ -271,24 +275,28 @@ class ParserPSPICE:
                     # line_split = line.rstrip('\n').split(':')  # Split line in two, before and after the "+ PARAMS:" command
                     # line_split = line_split[1].strip(' ')      # Take the second element and remove whitespaces at its extremities
                     line_split = line_split.split(' ')         # Split into different parameters
-                    self.circuit_data.Netlist[self.name_last_component].parameters = {}
+
+                    continue_Component = getattr(self.circuit_data.Netlist, self.name_last_component)
                     for par in line_split:                     # Loop through the parameters
                         par_split = par.split('=')             # Split into name and value of the parameter
                         if len(par_split) == 2:                # Only take into account entries with two elements (for example, avoid None)
                             name_par = str(par_split[0].strip(' '))
                             value_par = str(par_split[1].strip(' { } '))  # Strip spaces and bracket at the extremities
-                            self.circuit_data.Netlist[self.name_last_component].parameters[str(name_par)] = str(value_par)
+                            continue_Component.parameters[str(name_par)] = str(value_par)
+                    self.circuit_data.Netlist.__setattr__(self.name_last_component, continue_Component)
                     continue
                 elif self.flag_read_parametrized_component and '+' in line and line[0] == '+':  # This line defines additional parameters of the component
                     # Reminder: This type of line looks like this: + PARAMS: name1={value1} name2={value2} name3={value3}
                     line_split = line.rstrip('\n').partition('+')[2]        # Take the part of the string after the first "+" char
                     line_split = line_split.split(' ')                      # Split into different parameters
+                    continue_Component = getattr(self.circuit_data.Netlist, self.name_last_component)
                     for par in line_split:                                  # Loop through the parameters
                         par_split = par.split('=')                          # Split into name and value of the parameter
                         if len(par_split) == 2:                             # Only take into account entries with two elements (for example, avoid None)
                             name_par  = str(par_split[0].strip(' '))
                             value_par = str(par_split[1].strip(' { } '))  # Strip spaces and bracket at the extremities
-                            self.circuit_data.Netlist[self.name_last_component].parameters[str(name_par)] = str(value_par)
+                            continue_Component.parameters[str(name_par)] = str(value_par)
+                    self.circuit_data.Netlist.__setattr__(self.name_last_component, continue_Component)
                     continue
 
                 # If this part of the code is reached, the line defines standard component
@@ -297,10 +305,11 @@ class ParserPSPICE:
                 line_before, _, line_after = line_after.rstrip(' ').partition(')')  # Take the part of the string before and after the first ")" char
                 nodes = line_before.split(' ')
                 value = line_after.strip(' { } ')  # Strip spaces and bracket at the extremities
-                self.circuit_data.Netlist[name] = Component()
-                self.circuit_data.Netlist[name].type = 'standard component'
-                self.circuit_data.Netlist[name].nodes = nodes
-                self.circuit_data.Netlist[name].value = str(value)
+                new_Component = Component()
+                new_Component.type = 'standard component'
+                new_Component.nodes = nodes
+                new_Component.value = str(value)
+                self.circuit_data.Netlist.__setattr__(name, new_Component)
 
         # Simplify options keys if they have default values
         if self.circuit_data.Options.options_simulation == get_default_options():
@@ -394,12 +403,12 @@ class ParserPSPICE:
         # Prepare netlist
         rows_netlist = []
         rows_netlist.append(add_comment('**** Netlist ****'))  # Add header of this section
-        for s, name in enumerate(self.circuit_data.Netlist):
+        for s, name in enumerate(self.circuit_data.Netlist.__dict__.keys()):
             # Read keys
-            type        = self.circuit_data.Netlist[name].type
-            nodes       = self.circuit_data.Netlist[name].nodes
-            value       = self.circuit_data.Netlist[name].value
-            parameters  = self.circuit_data.Netlist[name].parameters
+            type        = getattr(getattr(self.circuit_data.Netlist, name), 'type')
+            nodes       = getattr(getattr(self.circuit_data.Netlist, name), 'nodes')
+            value       = getattr(getattr(self.circuit_data.Netlist, name), 'value')
+            parameters  = getattr(getattr(self.circuit_data.Netlist, name), 'parameters')
             # name, nodes, value, parameters, type = component.name, component.nodes, component.value, component.parameters, component.type
 
             # Check inputs
@@ -553,6 +562,9 @@ class ParserPSPICE:
         with open(full_path_file_name, "r") as stream:
             dictionary_yaml = yaml.safe_load(stream)
             self.circuit_data = DataModelCircuit(**dictionary_yaml)
+            for key in dictionary_yaml['Netlist'].keys():
+                new_Component = Component(**dictionary_yaml['Netlist'][key])
+                self.circuit_data.Netlist.__setattr__(key, new_Component)
         if verbose:
             print('File ' + full_path_file_name + ' read.')
 
